package com.sckj.project.service.task;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.sckj.project.config.ApiUrlConfig;
import com.sckj.project.domain.car.LargeCarDetail;
import com.sckj.project.domain.car.LargeCarRank;
import com.sckj.project.domain.car.LargeWarnDetail;
import com.sckj.project.service.car.ILargeCarDetailService;
import com.sckj.project.service.car.ILargeCarRankService;
import com.sckj.project.service.car.ILargeCarService;
import com.sckj.project.service.car.ILargeWarnDetailService;
import com.sckj.project.util.HttpRequestUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestClientException;

import java.util.List;
@Slf4j
@Service
public class CarTaskService {

    @Autowired
    private ILargeCarService largeCarService;

    @Autowired
    private ILargeCarDetailService largeCarDetailService;

    @Autowired
    private ILargeWarnDetailService largeWarnDetailService;

    @Autowired
    private ILargeCarRankService largeCarRankService;

    @Autowired
    private HttpRequestUtil httpRequestUtil;

    public JSONArray callExternalApi(String url) {
        try {
            ResponseEntity<String> response = httpRequestUtil.get(url);
            if (StringUtils.isEmpty(response.getBody())){
                return null;
            }
            return JSONUtil.parseObj(response.getBody()).getJSONArray("data");
        } catch (RestClientException e) {
            return null;
        }
    }

    public void myTask(){

        /*公务用车表*/
        largeCarService.saveOrUpdate(callExternalApi(ApiUrlConfig.getCarUrl()));

        /*公务用车年度增加减少表*/
        try {
            JSONArray array = callExternalApi(ApiUrlConfig.getCarChangeUrl());
            if (array == null){
                return;
            }
            List<LargeCarDetail> list = array.toList(LargeCarDetail.class);
            if (list.size() < 1){
                return;
            }
            largeCarDetailService.remove(new LambdaQueryWrapper<>());
            largeCarDetailService.saveBatch(list);
        } catch (Exception e) {
            e.getMessage();
        }

        /*公务用车预警明细表*/
        try {
            JSONArray array = callExternalApi(ApiUrlConfig.getCarWarnUrl());
            if (array == null){
                return;
            }
            List<LargeWarnDetail> list = array.toList(LargeWarnDetail.class);
            if (list.size() < 1){
                return;
            }
            largeWarnDetailService.remove(new LambdaQueryWrapper<>());
            largeWarnDetailService.saveBatch(list);
        } catch (Exception e) {
            e.getMessage();
        }

        /*公务用车单车活跃排名表*/
        try {
            JSONArray array = callExternalApi(ApiUrlConfig.getCarRankUrl());
            if (array == null){
                return;
            }
            List<LargeCarRank> list = array.toList(LargeCarRank.class);
            if (list.size() < 1){
                return;
            }
            largeCarRankService.remove(new LambdaQueryWrapper<>());
            largeCarRankService.saveBatch(list);
        } catch (Exception e) {
            e.getMessage();
        }
    }
}
